package VMOMI::HostInternetScsiHbaIscsiIpv6AddressIPv6AddressOperation;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
